StringUtil (py4j-java 0.10.9.7 API)

Package py4j

## Class StringUtil

- java.lang.Object
- - py4j.StringUtil

-     public class StringUtil
      extends java.lang.Object

  String utility class providing operations to escape and unescape new lines.

- - ### Field Summary

    Fields
    Modifier and Type | Field | Description
    --- | --- | ---
    `static char` | `ESCAPE_CHAR` |

  - ### Constructor Summary

    Constructors
    Constructor | Description
    --- | ---
    `StringUtil()` |

  - ### Method Summary

    All Methods Static Methods Concrete Methods
    Modifier and Type | Method | Description
    --- | --- | ---
    `static java.lang.String` | `escape​(java.lang.String original)` |
    `static java.lang.String` | `unescape​(java.lang.String escaped)` |

    - ### Methods inherited from class java.lang.Object

      `clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

- - ### Field Detail

    - #### ESCAPE_CHAR

          public static final char ESCAPE_CHAR

      See Also:
        Constant Field Values

  - ### Constructor Detail

    - #### StringUtil

          public StringUtil()

  - ### Method Detail

    - #### escape

          public static java.lang.String escape​(java.lang.String original)

    - #### unescape

          public static java.lang.String unescape​(java.lang.String escaped)